**SQLite INSERT Query**
=======================

The SQLite **INSERT INTO** Statement is used to add new rows of data into a
table in the database.

### **Syntax:**

There are two basic syntax of INSERT INTO statement as follows:

```sql
INSERT INTO TABLE_NAME (column1, column2, column3,...columnN)] 
VALUES (value1, value2, value3,...valueN);
```

Here, column1, column2,...columnN are the names of the columns in the table into
which you want to insert data.

You may not need to specify the column(s) name in the SQLite query if you are
adding values for all the columns of the table. But make sure the order of the
values is in the same order as the columns in the table. The SQLite INSERT INTO
syntax would be as follows:

```sql
INSERT INTO TABLE_NAME VALUES (value1,value2,value3,...valueN);
```

### **Example:**

**Consider you already have created COMPANY table in your testDB.db as
follows:**

```sql
sqlite> CREATE TABLE COMPANY(
   ID INT PRIMARY KEY     NOT NULL,
   NAME           TEXT    NOT NULL,
   AGE            INT     NOT NULL,
   ADDRESS        CHAR(50),
   SALARY         REAL
);
```

**Now, following statements would create six records in COMPANY table:**

```sql
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (1, 'Paul', 32, 'California', 20000.00 );
 
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (2, 'Allen', 25, 'Texas', 15000.00 );
 
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (3, 'Teddy', 23, 'Norway', 20000.00 );
 
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (4, 'Mark', 25, 'Rich-Mond ', 65000.00 );
 
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (5, 'David', 27, 'Texas', 85000.00 );
 
INSERT INTO COMPANY (ID,NAME,AGE,ADDRESS,SALARY)
VALUES (6, 'Kim', 22, 'South-Hall', 45000.00 );
```

You can create a record in COMPANY table using second syntax as follows:

```sql
INSERT INTO COMPANY VALUES (7, 'James', 24, 'Houston', 10000.00 );
```

**All the above statements would create following records in COMPANY table. Next
chapter will teach you how to display all these records from a table.**

```sql
ID          NAME        AGE         ADDRESS     SALARY
----------  ----------  ----------  ----------  ----------
1           Paul        32          California  20000.0
2           Allen       25          Texas       15000.0
3           Teddy       23          Norway      20000.0
4           Mark        25          Rich-Mond   65000.0
5           David       27          Texas       85000.0
6           Kim         22          South-Hall  45000.0
7           James       24          Houston     10000.0
```

**Populate one table using another table:**

You can populate data into a table through select statement over another table
provided another table has a set of fields, which are required to populate first
table. Here is the syntax:

```sql
INSERT INTO first_table_name [(column1, column2, ... columnN)]
   SELECT column1, column2, ...columnN
   FROM second_table_name
   [WHERE condition];
```
